@@ -65,6 +65,7 @@ def convert(
     fused_argmax_scale_ratio: Optional[float] = 0.5,
     replace_asin_to_pseudo_asin: Optional[bool] = False,
     replace_acos_to_pseudo_acos: Optional[bool] = False,
+    replace_prelu_to_pseudo_prelu: Optional[bool] = False,
     replace_leakyrelu_to_pseudo_leakyrelu: Optional[bool] = False,
     replace_power_to_pseudo_power: Optional[bool] = False,
     replace_gathernd_to_pseudo_gathernd: Optional[bool] = False,
@@ -243,6 +244,9 @@ def convert(
     replace_acos_to_pseudo_acos: Optional[bool]
         Replace Acos with a pseudo Acos.
 
+    replace_prelu_to_pseudo_prelu: Optional[bool]
+        Replace PReLU with a pseudo PReLU.
+
     replace_leakyrelu_to_pseudo_leakyrelu: Optional[bool]
         Replace LeakyReLU with a pseudo LeakyReLU.
 
@@ -446,6 +450,7 @@ def convert(
         'fused_argmax_scale_ratio': fused_argmax_scale_ratio,
         'replace_asin_to_pseudo_asin': replace_asin_to_pseudo_asin,
         'replace_acos_to_pseudo_acos': replace_acos_to_pseudo_acos,
+        'replace_prelu_to_pseudo_prelu': replace_prelu_to_pseudo_prelu,
         'replace_leakyrelu_to_pseudo_leakyrelu': replace_leakyrelu_to_pseudo_leakyrelu,
         'replace_power_to_pseudo_power': replace_power_to_pseudo_power,
         'replace_gathernd_to_pseudo_gathernd': replace_gathernd_to_pseudo_gathernd,
@@ -1013,6 +1018,12 @@ def main():
         action='store_true',
         help='Replace Acos with a pseudo Acos.'
     )
+    parser.add_argument(
+        '-rpr',
+        '--replace_prelu_to_pseudo_prelu',
+        action='store_true',
+        help='Replace PReLU with a pseudo PReLU.'
+    )
     parser.add_argument(
         '-rlr',
         '--replace_leakyrelu_to_pseudo_leakyrelu',
@@ -1115,6 +1126,7 @@ def main():
         fused_argmax_scale_ratio=args.fused_argmax_scale_ratio,
         replace_asin_to_pseudo_asin=args.replace_asin_to_pseudo_asin,
         replace_acos_to_pseudo_acos=args.replace_acos_to_pseudo_acos,
+        replace_prelu_to_pseudo_prelu=args.replace_prelu_to_pseudo_prelu,
         replace_leakyrelu_to_pseudo_leakyrelu=args.replace_leakyrelu_to_pseudo_leakyrelu,
         replace_power_to_pseudo_power=args.replace_power_to_pseudo_power,
         replace_gathernd_to_pseudo_gathernd=args.replace_gathernd_to_pseudo_gathernd,
